@@ -33,6 +33,7 @@ class _CustomMarkdownify(markdownify.MarkdownConverter):
                 secure=minio_conf.get("secure", True)
             )
             self.bucket_name = minio_conf["bucket_name"]
+            self.bucket_name = minio_conf["bucket_name"]
 
             # 如果 bucket 不存在则创建
             if not self.minio_client.bucket_exists(self.bucket_name):
@@ -53,7 +54,7 @@ class _CustomMarkdownify(markdownify.MarkdownConverter):
             length=len(image_bytes),
             content_type=f"image/{ext}"
         )
-        return f"http://{self.minio_client._endpoint_url}/{self.bucket_name}/{object_name}"
+        return f"http://{self.endpoint}/{self.bucket_name}/{object_name}"
 
     def convert_hn(
         self,
